from flask import Flask, render_template, request
import subprocess

import config

app = Flask(__name__)
app.config.from_object(config)

@app.route("/", methods=['POST', 'PUT'])
def index():
    data = request.data
    SAVE_FILE = "%s/%s" % (app.config['SAVE_FILE_PATH'], app.config['SAVE_FILE_NAME'])
    JS_FILE = "%s/%s" % (app.config['JS_FILE_PATH'], app.config['JS_FILE_NAME'])
    if data:
        with open(SAVE_FILE, "w") as x:
            x.write(data)

        COMMAND = "coffee --compile --output %s %s" % (app.config['JS_FILE_PATH'], SAVE_FILE)
        # Compile
        # File --output.coffee not found?
        subprocess.Popen(COMMAND, shell=True).wait()

        return open(JS_FILE).read()
    return "Nope"
 
def main():
    app.debug = config.DEBUG 
    app.run(host=config.HOST, port=config.PORT)

if __name__ == "__main__":
    main()
